==> huaweicloudsdklive-3.1.37-py2.py3-none-any.whl: huaweicloudsdklive/v1/model/list_snapshot_configs_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListSnapshotConfigsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'access_control_allow_internal': 'str',
        'access_control_allow_external': 'str',
        'domain': 'str',
        'app_name': 'str',
        'page': 'int',
        'size': 'int',
        'limit': 'int',
        'offset': 'int'
    }

    attribute_map = {
        'access_control_allow_internal': 'Access-Control-Allow-Internal',
        'access_control_allow_external': 'Access-Control-Allow-External',
        'domain': 'domain',
        'app_name': 'app_name',
        'page': 'page',
        'size': 'size',
        'limit': 'limit',
        'offset': 'offset'
    }

    def __init__(self, access_control_allow_internal=None, access_control_allow_external=None, domain=None, app_name=None, page=None, size=None, limit=None, offset=None):
        """ListSnapshotConfigsRequest

        The model defined in huaweicloud sdk

        :param access_control_allow_internal: 服务鉴权Token，服务开启鉴权，必须携带Access-Control-Allow-Internal访问服务。
        :type access_control_allow_internal: str
        :param access_control_allow_external: 服务鉴权Token，服务开启鉴权，必须携带Access-Control-Allow-External访问服务。
        :type access_control_allow_external: str
        :param domain: 域名
        :type domain: str
        :param app_name: 应用名称
        :type app_name: str
        :param page: 分页编号
        :type page: int
        :param size: 每页记录数，取值范围[1,100]
        :type size: int
        :param limit: 每页记录数  取值范围[1,100]  默认值：10
        :type limit: int
        :param offset: 偏移量，表示从此偏移量开始查询，offset大于等于0
        :type offset: int
        """
        
        

        self._access_control_allow_internal = None
        self._access_control_allow_external = None
        self._domain = None
        self._app_name = None
        self._page = None
        self._size = None
        self._limit = None
        self._offset = None
        self.discriminator = None

        if access_control_allow_internal is not None:
            self.access_control_allow_internal = access_control_allow_internal
        if access_control_allow_external is not None:
            self.access_control_allow_external = access_control_allow_external
        self.domain = domain
        if app_name is not None:
            self.app_name = app_name
        if page is not None:
            self.page = page
        if size is not None:
            self.size = size
        if limit is not None:
            self.limit = limit
        if offset is not None:
            self.offset = offset

    @property
    def access_control_allow_internal(self):
        """Gets the access_control_allow_internal of this ListSnapshotConfigsRequest.

        服务鉴权Token，服务开启鉴权，必须携带Access-Control-Allow-Internal访问服务。

        :return: The access_control_allow_internal of this ListSnapshotConfigsRequest.
        :rtype: str
        """
        return self._access_control_allow_internal

    @access_control_allow_internal.setter
    def access_control_allow_internal(self, access_control_allow_internal):
        """Sets the access_control_allow_internal of this ListSnapshotConfigsRequest.

        服务鉴权Token，服务开启鉴权，必须携带Access-Control-Allow-Internal访问服务。

        :param access_control_allow_internal: The access_control_allow_internal of this ListSnapshotConfigsRequest.
        :type access_control_allow_internal: str
        """
        self._access_control_allow_internal = access_control_allow_internal

    @property
    def access_control_allow_external(self):
        """Gets the access_control_allow_external of this ListSnapshotConfigsRequest.

        服务鉴权Token，服务开启鉴权，必须携带Access-Control-Allow-External访问服务。

        :return: The access_control_allow_external of this ListSnapshotConfigsRequest.
        :rtype: str
        """
        return self._access_control_allow_external

    @access_control_allow_external.setter
    def access_control_allow_external(self, access_control_allow_external):
        """Sets the access_control_allow_external of this ListSnapshotConfigsRequest.

        服务鉴权Token，服务开启鉴权，必须携带Access-Control-Allow-External访问服务。

        :param access_control_allow_external: The access_control_allow_external of this ListSnapshotConfigsRequest.
        :type access_control_allow_external: str
        """
        self._access_control_allow_external = access_control_allow_external

    @property
    def domain(self):
        """Gets the domain of this ListSnapshotConfigsRequest.

        域名

        :return: The domain of this ListSnapshotConfigsRequest.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this ListSnapshotConfigsRequest.

        域名

        :param domain: The domain of this ListSnapshotConfigsRequest.
        :type domain: str
        """
        self._domain = domain

    @property
    def app_name(self):
        """Gets the app_name of this ListSnapshotConfigsRequest.

        应用名称

        :return: The app_name of this ListSnapshotConfigsRequest.
        :rtype: str
        """
        return self._app_name

    @app_name.setter
    def app_name(self, app_name):
        """Sets the app_name of this ListSnapshotConfigsRequest.

        应用名称

        :param app_name: The app_name of this ListSnapshotConfigsRequest.
        :type app_name: str
        """
        self._app_name = app_name

    @property
    def page(self):
        """Gets the page of this ListSnapshotConfigsRequest.

        分页编号

        :return: The page of this ListSnapshotConfigsRequest.
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this ListSnapshotConfigsRequest.

        分页编号

        :param page: The page of this ListSnapshotConfigsRequest.
        :type page: int
        """
        self._page = page

    @property
    def size(self):
        """Gets the size of this ListSnapshotConfigsRequest.

        每页记录数，取值范围[1,100]

        :return: The size of this ListSnapshotConfigsRequest.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ListSnapshotConfigsRequest.

        每页记录数，取值范围[1,100]

        :param size: The size of this ListSnapshotConfigsRequest.
        :type size: int
        """
        self._size = size

    @property
    def limit(self):
        """Gets the limit of this ListSnapshotConfigsRequest.

        每页记录数  取值范围[1,100]  默认值：10

        :return: The limit of this ListSnapshotConfigsRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListSnapshotConfigsRequest.

        每页记录数  取值范围[1,100]  默认值：10

        :param limit: The limit of this ListSnapshotConfigsRequest.
        :type limit: int
        """
        self._limit = limit

    @property
    def offset(self):
        """Gets the offset of this ListSnapshotConfigsRequest.

        偏移量，表示从此偏移量开始查询，offset大于等于0

        :return: The offset of this ListSnapshotConfigsRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListSnapshotConfigsRequest.

        偏移量，表示从此偏移量开始查询，offset大于等于0

        :param offset: The offset of this ListSnapshotConfigsRequest.
        :type offset: int
        """
        self._offset = offset

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSnapshotConfigsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdklive-3.1.38-py2.py3-none-any.whl: huaweicloudsdklive/v1/model/list_snapshot_configs_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListSnapshotConfigsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'domain': 'str',
        'app_name': 'str',
        'limit': 'int',
        'offset': 'int'
    }

    attribute_map = {
        'domain': 'domain',
        'app_name': 'app_name',
        'limit': 'limit',
        'offset': 'offset'
    }

    def __init__(self, domain=None, app_name=None, limit=None, offset=None):
        """ListSnapshotConfigsRequest

        The model defined in huaweicloud sdk

        :param domain: 域名
        :type domain: str
        :param app_name: 应用名称
        :type app_name: str
        :param limit: 每页记录数  取值范围[1,100]  默认值：10
        :type limit: int
        :param offset: 偏移量，表示从此偏移量开始查询，offset大于等于0
        :type offset: int
        """
        
        

        self._domain = None
        self._app_name = None
        self._limit = None
        self._offset = None
        self.discriminator = None

        self.domain = domain
        if app_name is not None:
            self.app_name = app_name
        if limit is not None:
            self.limit = limit
        if offset is not None:
            self.offset = offset

    @property
    def domain(self):
        """Gets the domain of this ListSnapshotConfigsRequest.

        域名

        :return: The domain of this ListSnapshotConfigsRequest.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this ListSnapshotConfigsRequest.

        域名

        :param domain: The domain of this ListSnapshotConfigsRequest.
        :type domain: str
        """
        self._domain = domain

    @property
    def app_name(self):
        """Gets the app_name of this ListSnapshotConfigsRequest.

        应用名称

        :return: The app_name of this ListSnapshotConfigsRequest.
        :rtype: str
        """
        return self._app_name

    @app_name.setter
    def app_name(self, app_name):
        """Sets the app_name of this ListSnapshotConfigsRequest.

        应用名称

        :param app_name: The app_name of this ListSnapshotConfigsRequest.
        :type app_name: str
        """
        self._app_name = app_name

    @property
    def limit(self):
        """Gets the limit of this ListSnapshotConfigsRequest.

        每页记录数  取值范围[1,100]  默认值：10

        :return: The limit of this ListSnapshotConfigsRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListSnapshotConfigsRequest.

        每页记录数  取值范围[1,100]  默认值：10

        :param limit: The limit of this ListSnapshotConfigsRequest.
        :type limit: int
        """
        self._limit = limit

    @property
    def offset(self):
        """Gets the offset of this ListSnapshotConfigsRequest.

        偏移量，表示从此偏移量开始查询，offset大于等于0

        :return: The offset of this ListSnapshotConfigsRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListSnapshotConfigsRequest.

        偏移量，表示从此偏移量开始查询，offset大于等于0

        :param offset: The offset of this ListSnapshotConfigsRequest.
        :type offset: int
        """
        self._offset = offset

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSnapshotConfigsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
